pub struct BlockValidationFutures {
pub block_task: BlockValidationFuture,
pub virtual_state_task: BlockValidationFuture,
}Expand description
A struct returned by consensus for block validation processing calls
Fields
block_task: BlockValidationFutureA future triggered when block processing is completed (header and body processing)
virtual_state_task: BlockValidationFutureA future triggered when DAG state which included this block has been processed by the virtual processor
(exceptions are header-only blocks and trusted blocks which have the future completed before virtual
processing along with the block_task)