pub struct Block {
pub header: Arc<Header>,
pub transactions: Arc<Vec<Transaction>>,
}Expand description
A block structure where the inner header and transactions are wrapped by Arcs for cheap cloning and for cross-thread safety and immutability. Note: no need to wrap this struct with an additional Arc.
Fields
header: Arc<Header>transactions: Arc<Vec<Transaction>>Implementations
Sourceimpl Block
impl Block
pub fn new(header: Header, txs: Vec<Transaction>) -> Self
pub fn from_arcs( header: Arc<Header>, transactions: Arc<Vec<Transaction>>, ) -> Self
pub fn from_header_arc(header: Arc<Header>) -> Self
pub fn from_header(header: Header) -> Self
pub fn is_header_only(&self) -> bool
pub fn hash(&self) -> Hash
Sourcepub fn from_precomputed_hash(hash: Hash, parents: Vec<Hash>) -> Block
pub fn from_precomputed_hash(hash: Hash, parents: Vec<Hash>) -> Block
WARNING: To be used for test purposes only
pub fn asses_for_cache(&self) -> Option<()>