pub struct VirtualStateApproxId { /* private fields */ }Expand description
An opaque data structure representing a unique approximate identifier for virtual state. Note that it is approximate in the sense that in rare cases a slightly different virtual state might produce the same identifier, hence it should be used for cache-like heuristics only
Implementations
Sourceimpl VirtualStateApproxId
impl VirtualStateApproxId
pub fn new(daa_score: u64, blue_work: BlueWorkType, sink: Hash) -> Self