pub enum BlockStatus {
StatusInvalid,
StatusUTXOValid,
StatusUTXOPendingVerification,
StatusDisqualifiedFromChain,
StatusHeaderOnly,
}Variants
StatusInvalid
StatusInvalid indicates that the block is invalid.
StatusUTXOValid
StatusUTXOValid indicates the block is valid from any UTXO related aspects and has passed all the other validations as well.
StatusUTXOPendingVerification
StatusUTXOPendingVerification indicates that the block is pending verification against its past UTXO-Set, either because it was not yet verified since the block was never in the selected parent chain, or if the block violates finality.
StatusDisqualifiedFromChain
StatusDisqualifiedFromChain indicates that the block is not eligible to be a selected parent.
StatusHeaderOnly
StatusHeaderOnly indicates that the block transactions are not held (pruned or wasn’t added yet)
Implementations
Sourceimpl BlockStatus
impl BlockStatus
pub fn has_block_header(self) -> bool
pub fn is_header_only(self) -> bool
pub fn has_block_body(self) -> bool
pub fn is_utxo_valid_or_pending(self) -> bool
pub fn is_valid(self) -> bool
pub fn is_invalid(self) -> bool