NetworkId

Struct NetworkId 

pub struct NetworkId {
    pub network_type: NetworkType,
    pub suffix: Option<u32>,
}
NetworkId is a unique identifier for a kaspa network instance. It is composed of a network type and an optional suffix.

@category Consensus

Fields

network_type: NetworkTypesuffix: Option<u32>

Implementations

Source

impl NetworkId

pub const fn new(network_type: NetworkType) -> Self

pub fn try_new(network_type: NetworkType) -> Result<Self, NetworkIdError>

pub const fn with_suffix(network_type: NetworkType, suffix: u32) -> Self

pub fn network_type(&self) -> NetworkType

pub fn is_mainnet(&self) -> bool

pub fn suffix(&self) -> Option<u32>

pub fn default_p2p_port(&self) -> u16

pub fn iter() -> impl Iterator<Item = Self>

pub fn to_prefixed(&self) -> String

Returns a textual description of the network prefixed with kaspa-

pub fn from_prefixed(prefixed: &str) -> Result<Self, NetworkIdError>

Source

impl NetworkId

pub fn ctor(value: &JsValue) -> Result<NetworkId, NetworkIdError>

pub fn js_id(&self) -> String

pub fn js_to_string(&self) -> String

pub fn js_address_prefix(&self) -> String

Methods from Deref<Target = NetworkType>