pub struct PruningPointTrustedData {
pub anticone: Vec<Hash>,
pub daa_window_blocks: Vec<TrustedHeader>,
pub ghostdag_blocks: Vec<TrustedGhostdagData>,
}Fields
anticone: Vec<Hash>The pruning point anticone from virtual PoV
daa_window_blocks: Vec<TrustedHeader>Union of DAA window data required to verify blocks in the future of the pruning point
ghostdag_blocks: Vec<TrustedGhostdagData>Union of GHOSTDAG data required to verify blocks in the future of the pruning point