pub struct TrustedBlock {
pub block: Block,
pub ghostdag: ExternalGhostdagData,
}Expand description
Represents an externally provided block with associated Ghostdag data which is only partially validated by the consensus layer. Note there is no actual trust but rather these blocks are indirectly validated through the PoW mined over them
Fields
block: Blockghostdag: ExternalGhostdagDataImplementations
Sourceimpl TrustedBlock
impl TrustedBlock
pub fn new(block: Block, ghostdag: ExternalGhostdagData) -> Self