MutableTransaction

Struct MutableTransaction 

pub struct MutableTransaction<T: AsRef<Transaction> = Arc<Transaction>> {
    pub tx: T,
    pub entries: Vec<Option<UtxoEntry>>,
    pub calculated_fee: Option<u64>,
    pub calculated_compute_mass: Option<u64>,
}
Represents a generic mutable/readonly/pointer transaction type along with partially filled UTXO entry data and optional fee and mass

Fields

tx: T

The inner transaction

entries: Vec<Option<UtxoEntry>>

Partially filled UTXO entry data

calculated_fee: Option<u64>

Populated fee

calculated_compute_mass: Option<u64>

Populated compute mass (does not include the storage mass)

Implementations

Source

impl<T: AsRef<Transaction>> MutableTransaction<T>

pub fn new(tx: T) -> Self

pub fn id(&self) -> TransactionId

pub fn with_entries(tx: T, entries: Vec<UtxoEntry>) -> Self

pub fn as_verifiable(&self) -> impl VerifiableTransaction + '_

Returns the tx wrapped as a VerifiableTransaction. Note that this function must be called only once all UTXO entries are populated, otherwise it panics.

pub fn is_verifiable(&self) -> bool

pub fn is_fully_populated(&self) -> bool

pub fn missing_outpoints( &self, ) -> impl Iterator<Item = TransactionOutpoint> + '_

pub fn clear_entries(&mut self)

pub fn calculated_feerate(&self) -> Option<f64>

Returns the calculated feerate. The feerate is calculated as the amount of fee this transactions pays per gram of the full contextual (compute & storage) mass. The function returns a value when calculated fee exists and the contextual mass is greater than zero, otherwise None is returned.

pub fn mempool_estimated_bytes(&self) -> usize

A function for estimating the amount of memory bytes used by this transaction (dedicated to mempool usage). We need consistency between estimation calls so only this function should be used for this purpose since estimate_mem_bytes is sensitive to pointer wrappers such as Arc

pub fn has_parent(&self, possible_parent: TransactionId) -> bool

pub fn has_parent_in_set( &self, possible_parents: &HashSet<TransactionId>, ) -> bool

Source

impl MutableTransaction

Specialized impl for T=Arc<Transaction>

pub fn from_tx(tx: Transaction) -> Self