pub struct TransactionMass(/* private fields */);Trait Implementations
Sourceimpl BorshDeserialize for TransactionMass
impl BorshDeserialize for TransactionMass
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransactionMass
impl BorshSerialize for TransactionMass
Sourceimpl Clone for TransactionMass
impl Clone for TransactionMass
Sourceimpl Debug for TransactionMass
impl Debug for TransactionMass
Sourceimpl Default for TransactionMass
impl Default for TransactionMass
Sourcefn default() -> TransactionMass
fn default() -> TransactionMass
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TransactionMass
impl<'de> Deserialize<'de> for TransactionMass
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionMass
impl PartialEq for TransactionMass
Sourceimpl Serialize for TransactionMass
impl Serialize for TransactionMass
impl Eq for TransactionMass