pub struct TrustedHeader {
pub header: Arc<Header>,
pub ghostdag: ExternalGhostdagData,
}Expand description
Represents an externally provided header with associated Ghostdag data which is only partially validated by the consensus layer. Note there is no actual trust but rather these headers are indirectly validated through the PoW mined over them
Fields
header: Arc<Header>ghostdag: ExternalGhostdagDataImplementations
Sourceimpl TrustedHeader
impl TrustedHeader
pub fn new(header: Arc<Header>, ghostdag: ExternalGhostdagData) -> Self