pub struct Transaction {
pub version: u16,
pub inputs: Vec<TransactionInput>,
pub outputs: Vec<TransactionOutput>,
pub lock_time: u64,
pub subnetwork_id: SubnetworkId,
pub gas: u64,
pub payload: Vec<u8>,
/* private fields */
}Expand description
Represents a Kaspa transaction
Fields
version: u16inputs: Vec<TransactionInput>outputs: Vec<TransactionOutput>lock_time: u64subnetwork_id: SubnetworkIdgas: u64payload: Vec<u8>Implementations
Sourceimpl Transaction
impl Transaction
pub fn new( version: u16, inputs: Vec<TransactionInput>, outputs: Vec<TransactionOutput>, lock_time: u64, subnetwork_id: SubnetworkId, gas: u64, payload: Vec<u8>, ) -> Self
pub fn new_non_finalized( version: u16, inputs: Vec<TransactionInput>, outputs: Vec<TransactionOutput>, lock_time: u64, subnetwork_id: SubnetworkId, gas: u64, payload: Vec<u8>, ) -> Self
Sourceimpl Transaction
impl Transaction
Sourcepub fn is_coinbase(&self) -> bool
pub fn is_coinbase(&self) -> bool
Determines whether or not a transaction is a coinbase transaction. A coinbase transaction is a special transaction created by miners that distributes fees and block subsidy to the previous blocks’ miners, and specifies the script_pub_key that will be used to pay the current miner in future blocks.
Sourcepub fn id(&self) -> TransactionId
pub fn id(&self) -> TransactionId
Returns the transaction ID
Sourcepub fn set_mass(&self, mass: u64)
pub fn set_mass(&self, mass: u64)
Set the mass field of this transaction. The mass field is expected depending on hard-forks which are currently activated only on some testnets. The field has no effect on tx ID so no need to finalize following this call.
pub fn mass(&self) -> u64
pub fn with_mass(self, mass: u64) -> Self